//[mahjong-utils](../../../index.md)/[mahjongutils.models](../index.md)/[Kan](index.md)/[Kan](-kan.md)

# Kan

[common]\
constructor(tile: [Tile](../-tile/index.md), ankan: [Boolean](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-boolean/index.html) = false)
